@@ -3,15 +3,16 @@
 from functools import wraps
 
 import elasticsearch
-from elasticsearch import Elasticsearch, VERSION as ES_VERSION
+from elasticsearch import VERSION as ES_VERSION
+from elasticsearch import Elasticsearch
 
 from trytond.exceptions import RateLimitException
-from trytond.i18n import lazy_gettext, gettext
+from trytond.i18n import gettext, lazy_gettext
 from trytond.model import ModelSQL, Unique, fields
-from trytond.pool import PoolMeta, Pool
+from trytond.pool import Pool, PoolMeta
 from trytond.pyson import Eval
 
-from .exceptions import LoginException, NotFound, BadRequest
+from .exceptions import BadRequest, LoginException, NotFound
 
 
 def migrate_doc_type(func):
@@ -81,15 +82,13 @@ class Shop(metaclass=PoolMeta):
         states={
             'required': Eval('type') == 'vsf',
             'invisible': Eval('type') != 'vsf',
-            },
-        depends=['type'])
+            })
     vsf_elasticsearch_index = fields.Char(
         "Elasticsearch Index",
         states={
             'required': Eval('type') == 'vsf',
             'invisible': Eval('type') != 'vsf',
-            },
-        depends=['type'])
+            })
 
     @classmethod
     def __setup__(cls):
@@ -164,7 +163,8 @@ class Shop(metaclass=PoolMeta):
             for template in templates:
                 template_products = template.get_vsf_products(shop)
                 price, tax = min(
-                    (prices[p.id], taxes[p.id]) for p in template_products)
+                    (prices[p.id], taxes[p.id]) for p in template_products
+                    if prices[p.id] is not None and taxes[p.id] is not None)
                 entity = template.get_vsf_entity(shop, price=price, tax=tax)
                 entity['configurable_children'] = [
                     product.get_vsf_entity(
@@ -501,7 +501,7 @@ class ShopShipmentCost(metaclass=PoolMeta):
         for carrier in sale.available_carriers:
             method = carrier.get_vsf()
             sale.carrier = carrier
-            method['price_incl_tax'] = sale.compute_shipment_cost()
+            method['price_incl_tax'] = sale.compute_shipment_cost(carrier)
             methods.append(method)
         return methods
 
@@ -542,7 +542,7 @@ class ShopVSFIdentifier(ModelSQL):
 
 
 class ShopVSFIdentifierMixin:
-
+    __slots__ = ()
     vsf_identifier = fields.Many2One(
         'web.shop.vsf_identifier',
         lazy_gettext('web_shop_vue_storefront.msg_vsf_identifier'),
